@@ -1,10 +1,10 @@
-# @(#)$Id: Storage.pm 248 2011-04-01 02:35:24Z pjf $
+# @(#)$Id: Storage.pm 268 2011-05-15 17:41:41Z pjf $
 
 package File::DataClass::Storage;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.3.%d', q$Rev: 248 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.4.%d', q$Rev: 268 $ =~ /\d+/gmx );
 
 use Class::Null;
 use English qw(-no_match_vars);
@@ -15,7 +15,7 @@ use Hash::Merge qw(merge);
 use Moose;
 use Try::Tiny;
 
-with qw(File::DataClass::Util);
+extends qw(File::DataClass);
 
 has 'backup' => is => 'rw', isa => 'Str',    default  => NUL;
 has 'extn'   => is => 'rw', isa => 'Str',    default  => NUL;
@@ -244,7 +244,7 @@ File::DataClass::Storage - Storage base class
 
 =head1 Version
 
-0.3.$Revision: 248 $
+0.4.$Revision: 268 $
 
 =head1 Synopsis
 
